# -*-makefile-*-
#
# Copyright (C) 2010 by Juergen Kilb
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_GRAPHICS_DDK) += graphics_ddk

#
# Note to developers:  The source tarball used here is made from the tarball
# OPBU_GFX_DDK_GLP1.6.6/ppa/packages/sgx-lib_1.9.0.6.1.orig.tar.gz and diff
# file OPBU_GFX_DDK_GLP1.6.6/ppa/packages/sgx-lib_1.9.0.6.1-1glp57.diff.gz
# included in TI's Graphics DDK package.  We do not distribute the whole
# DDK as it is not redistributable.  Rather, we just distribute the 
# eurasia_km directory which is under GPL.
# To create the tarball included in local_src from the TI DDK:
#   unzip OPBU_GFX_DDK_GLP1.6.6.zip
#   cd OPBU_GFX_DDK_GLP1.6.6/ppa/packages
#   dpkg-source -x sgx-lib_1.9.0.6.1-1glp57.dsc
#   export QUILT_PATCHES=debian/patches
#   cd sgx-lib-1.9.0.6.1
#   quilt push -a
#   cd ..
#   tar czf /tmp/sgx-lib_1.9.0.6.1.tar.gz sgx-lib-1.9.0.6.1/eurasia_km
#

#
# Paths and names
#
GRAPHICS_DDK_VERSION	:= 1.9.0.6.1
GRAPHICS_DDK_MD5	:= 7448b05cf4a47644ea81737490b73e98
GRAPHICS_DDK		:= graphics_ddk
GRAPHICS_DDK_SUFFIX	:= tar.gz
GRAPHICS_DDK_URL	:= file://$(PTXDIST_WORKSPACE)/local_src/sgx-lib_$(GRAPHICS_DDK_VERSION).$(GRAPHICS_DDK_SUFFIX)
GRAPHICS_DDK_DIR	:= $(BUILDDIR)/$(GRAPHICS_DDK)
GRAPHICS_DDK_LICENSE	:= GPL
GRAPHICS_DDK_SUBDIR	:= eurasia_km/eurasiacon/build/linux2/omap4430_linux

ifdef PTXCONF_GRAPHICS_DDK 
$(STATEDIR)/kernel.targetinstall.post: $(STATEDIR)/graphics_ddk.targetinstall
endif

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

# ----------------------------------------------------------------------------
# Extract 
# ----------------------------------------------------------------------------
$(STATEDIR)/graphics_ddk.extract:
	@$(call targetinfo)
	@$(call clean, $(GRAPHICS_DDK_DIR))
	@$(call extract, GRAPHICS_DDK)
	@$(call touch)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------
GRAPHICS_DDK_PATH	:= PATH=$(CROSS_PATH)
BUILD 			:= release
GRAPHICS_DDK_ENV	:= BUILD=$(BUILD) \
                		DISCIMAGE=$(SYSROOT) \
				KERNELDIR=$(BUILDDIR)/linux-3.4 \
                		CROSS_COMPILE=$(PTXCONF_COMPILER_PREFIX) \
                		ARCH=arm

$(STATEDIR)/graphics_ddk.prepare:
	@$(call targetinfo)
	# Hack: omap_drm.h and omap_drv.h in include are symbolic links
	# in the kernel git tree.  But ptxdist uses patch and that can not
	# create files which are symbolic links.  We do so here.
	rm -f $(BUILDDIR)/linux-3.4/include/linux/omap_drm.h
	cp $(BUILDDIR)/linux-3.4/drivers/staging/omapdrm/omap_drm.h \
		$(BUILDDIR)/linux-3.4/include/linux/omap_drm.h
	rm -f $(BUILDDIR)/linux-3.4/include/linux/omap_drv.h
	cp $(BUILDDIR)/linux-3.4/drivers/staging/omapdrm/omap_drv.h \
		$(BUILDDIR)/linux-3.4/include/linux/omap_drv.h
	@$(call touch)

# ----------------------------------------------------------------------------
#  Compile:
# ----------------------------------------------------------------------------
$(STATEDIR)/graphics_ddk.compile:

	@$(call targetinfo)
	$(MAKE) $(GRAPHICS_DDK_ENV) \
		-C $(GRAPHICS_DDK_DIR)/$(GRAPHICS_DDK_SUBDIR)
	@$(call touch)
# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------
$(STATEDIR)/graphics_ddk.install:

	@$(call targetinfo)
	mkdir -p $(SYSROOT)/usr/include/include4
	install $(GRAPHICS_DDK_DIR)/eurasia_km/include4/img_types.h \
			$(SYSROOT)/usr/include/include4/img_types.h
	install $(GRAPHICS_DDK_DIR)/eurasia_km/include4/img_defs.h \
			$(SYSROOT)/usr/include/include4/img_defs.h
	@$(call touch)
# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

$(STATEDIR)/graphics_ddk.targetinstall:
	
	@$(call targetinfo)
	@$(call install_init,  graphics_ddk)
	@$(call install_copy, graphics_ddk, 0, 0, 0755, \
		$(GRAPHICS_DDK_DIR)/eurasia_km/eurasiacon/binary2_omap4430_linux_release/target/omapdrm_pvr.ko, \
		/lib/modules/3.4.11$(PTXCONF_PROJECT_VERSION)/extra/omapdrm_pvr.ko, n)

ifdef PTXCONF_INITMETHOD_BBINIT
ifdef PTXCONF_GRAPHICS_DDK_STARTSCRIPT
	@$(call install_alternative, graphics_ddk, 0, 0, 0755, /etc/init.d/rc.pvr)

ifneq ($(call remove_quotes,$(PTXCONF_GRAPHICS_DDK_BBINIT_LINK)),)
	@$(call install_link, graphics_ddk, \
		../init.d/rc.pvr, \
		/etc/rc.d/$(PTXCONF_GRAPHICS_DDK_BBINIT_LINK))
endif
endif
endif
	@$(call install_finish, graphics_ddk)
	@$(call touch)

# vim: syntax=make
