# -*-makefile-*-
#
# Copyright (C) 2006 by Erwin Rol
#               2010 by Marc Kleine-Budde <mkl@pengutronix.de>
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_LIBDRM) += libdrm

#
# Paths and names
#
LIBDRM_VERSION	:= 2.4.39
LIBDRM_MD5	:= 0ae70ae6dc844d77d20c7fca73041dd3
LIBDRM		:= libdrm-$(LIBDRM_VERSION)
LIBDRM_SUFFIX	:= tar.gz
LIBDRM_URL	:= http://dri.freedesktop.org/libdrm/$(LIBDRM).$(LIBDRM_SUFFIX)
LIBDRM_SOURCE	:= $(SRCDIR)/$(LIBDRM).$(LIBDRM_SUFFIX)
LIBDRM_DIR	:= $(BUILDDIR)/$(LIBDRM)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

#
# autoconf
#

CONF_OPT += --$(call ptx/endis, PTXCONF_LIBDRM_INTEL)-intel
CONF_OPT += --$(call ptx/endis, PTXCONF_LIBDRM_LIBKMS)-libkms
CONF_OPT += --$(call ptx/endis, PTXCONF_LIBDRM_OMAP)-omap-experimental-api

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

$(STATEDIR)/libdrm.prepare:
	@$(call targetinfo)
	echo CONF_OPT $(CONF_OPT)
	export PKG_CONFIG_PATH=$(SYSROOT)/usr/lib/pkgconfig && \
	cd $(LIBDRM_DIR) &&  \
	chmod a+x autogen.sh && \
	CFLAGS=-I$(SYSROOT)/usr/include \
	LDFLAGS=-L$(SYSROOT)/usr/lib \
	./autogen.sh --prefix=$(SYSROOT) --host=arm-cortexa9-linux-gnueabi \
		$(CONF_OPT)
	@$(call touch)

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------
$(STATEDIR)/libdrm.install:
	@$(call targetinfo)

#	These are required for building sgx-lib/eurasia
	mkdir -p $(SYSROOT)/usr/include/libdrm
	install $(LIBDRM_DIR)/libdrm.pc $(SYSROOT)/usr/lib/pkgconfig
	install $(LIBDRM_DIR)/omap/libdrm_omap.pc $(SYSROOT)/usr/lib/pkgconfig
ifdef PTXCONF_LIBDRM_LIBKMS
	install $(LIBDRM_DIR)/libkms/libkms.pc $(SYSROOT)/usr/lib/pkgconfig
	install $(LIBDRM_DIR)/libkms/libkms.h $(SYSROOT)/usr/include/libdrm
	install $(LIBDRM_DIR)/libkms/.libs/libkms.so.1.0.0 $(SYSROOT)/usr/lib
	install $(LIBDRM_DIR)/libkms/.libs/libkms.so.1 $(SYSROOT)/usr/lib
	install $(LIBDRM_DIR)/libkms/.libs/libkms.so $(SYSROOT)/usr/lib
endif
	install $(LIBDRM_DIR)/xf86drm.h $(SYSROOT)/usr/include/libdrm
	install $(LIBDRM_DIR)/xf86drmMode.h $(SYSROOT)/usr/include/libdrm
	install $(LIBDRM_DIR)/include/drm/drm.h $(SYSROOT)/usr/include/libdrm
	install $(LIBDRM_DIR)/include/drm/drm_mode.h $(SYSROOT)/usr/include/libdrm
	install $(LIBDRM_DIR)/include/drm/drm_fourcc.h $(SYSROOT)/usr/include/libdrm
	install $(LIBDRM_DIR)/omap/omap_drm.h $(SYSROOT)/usr/include/libdrm
	install $(LIBDRM_DIR)/omap/omap_drmif.h $(SYSROOT)/usr/include/libdrm

	install $(LIBDRM_DIR)/.libs/libdrm.so.2.4.0 $(SYSROOT)/usr/lib
	install $(LIBDRM_DIR)/.libs/libdrm.so.2 $(SYSROOT)/usr/lib
	install $(LIBDRM_DIR)/.libs/libdrm.so $(SYSROOT)/usr/lib
	install $(LIBDRM_DIR)/omap/.libs/libdrm_omap.so.1.0.0 $(SYSROOT)/usr/lib
	install $(LIBDRM_DIR)/omap/.libs/libdrm_omap.so.1 $(SYSROOT)/usr/lib
	install $(LIBDRM_DIR)/omap/.libs/libdrm_omap.so $(SYSROOT)/usr/lib

	@$(call touch)

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

$(STATEDIR)/libdrm.targetinstall:
	@$(call targetinfo)

	@$(call install_init, libdrm)
	@$(call install_fixup, libdrm,PRIORITY,optional)
	@$(call install_fixup, libdrm,SECTION,base)
	@$(call install_fixup, libdrm,AUTHOR,"Robert Schwebel <r.schwebel@pengutronix.de>")
	@$(call install_fixup, libdrm,DESCRIPTION,missing)

	@$(call install_copy, libdrm, 0, 0, 0644, \
		$(LIBDRM_DIR)/.libs/libdrm.so.2.4.0, \
		/usr/lib/libdrm.so.2.4.0)
	@$(call install_link, libdrm, libdrm.so.2.4.0, /usr/lib/libdrm.so.2)
	@$(call install_link, libdrm, libdrm.so.2.4.0, /usr/lib/libdrm.so)


ifdef PTXCONF_LIBDRM_LIBKMS
	@$(call install_copy, libdrm, 0, 0, 0644, \
		$(LIBDRM_DIR)/libkms/.libs/libkms.so.1.0.0, \
		/usr/lib/libkms.so.1.0.0)
	@$(call install_link, libdrm, libkms.so.1.0.0, /usr/lib/libkms.so)
	@$(call install_link, libdrm, libkms.so.1.0.0, /usr/lib/libkms.so.1)
endif
ifdef PTXCONF_LIBDRM_INTEL
	@$(call install_lib, libdrm, 0, 0, 0644, libdrm_intel)
endif
ifdef PTXCONF_LIBDRM_OMAP
	@$(call install_copy, libdrm, 0, 0, 0644, \
		$(LIBDRM_DIR)/omap/.libs/libdrm_omap.so.1.0.0, \
		/usr/lib/libdrm_omap.so.1.0.0)
	@$(call install_link, libdrm, libdrm_omap.so.1.0.0, /usr/lib/libdrm_omap.so.1)
	@$(call install_link, libdrm, libdrm_omap.so.1.0.0, /usr/lib/libdrm_omap.so)
endif
	@$(call install_finish, libdrm)

	@$(call touch)

# vim: syntax=make
