# -*-makefile-*-
#
# Copyright (C) 2006 by Erwin Rol
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_MESALIB) += mesalib

#
# Paths and names
#
MESALIB_VERSION	:= 9.0
MESALIB_MD5	:= 60e557ce407be3732711da484ab3db6c
MESALIB		:= MesaLib-$(MESALIB_VERSION)
MESALIB_SUFFIX	:= tar.bz2
MESALIB_URL	:= ftp://ftp.freedesktop.org/pub/mesa/$(MESALIB_VERSION)/$(MESALIB).$(MESALIB_SUFFIX)
MESALIB_SOURCE	:= $(SRCDIR)/$(MESALIB).$(MESALIB_SUFFIX)
MESALIB_DIR	:= $(BUILDDIR)/Mesa-$(MESALIB_VERSION)

ifdef PTXCONF_MESALIB
ifeq ($(shell $(PTXDIST_TOPDIR)/bin/python -c 'import libxml2' 2>/dev/null || echo no),no)
    $(warning *** libxml2 Python module is required for Mesa)
    $(error please install python-libxml2 (debian))
endif
endif

ifdef PTXCONF_ARCH_X86
MESALIB_DRI_DRIVERS-$(PTXCONF_MESALIB_DRI_I915)		+= i915
MESALIB_DRI_DRIVERS-$(PTXCONF_MESALIB_DRI_I965)		+= i965
endif
MESALIB_DRI_DRIVERS-$(PTXCONF_MESALIB_DRI_NOUVEAU)	+= nouveau
MESALIB_DRI_DRIVERS-$(PTXCONF_MESALIB_DRI_R200)		+= r200
MESALIB_DRI_DRIVERS-$(PTXCONF_MESALIB_DRI_RADEON)	+= radeon
MESALIB_DRI_DRIVERS-$(PTXCONF_MESALIB_DRI_SWRAST)	+= swrast

ifdef PTXCONF_ARCH_X86
MESALIB_GALLIUM_DRIVERS-$(PTXCONF_MESALIB_DRI_I915)	+= i915
endif
ifndef PTXCONF_ARCH_X86 # needs llvm
MESALIB_GALLIUM_DRIVERS-$(PTXCONF_MESALIB_DRI_R300)	+= r300
endif
MESALIB_GALLIUM_DRIVERS-$(PTXCONF_MESALIB_DRI_R600)	+= r600
MESALIB_GALLIUM_DRIVERS-$(PTXCONF_MESALIB_DRI_NOUVEAU)	+= nouveau
MESALIB_GALLIUM_DRIVERS-$(PTXCONF_MESALIB_DRI_SWRAST)	+= swrast

MESALIB_DRI_LIBS-y += $(MESALIB_DRI_DRIVERS-y) $(MESALIB_GALLIUM_DRIVERS-y)

MESALIB_CONF_TOOL	:= NO
MESALIB_CONF	:= \
	$(CROSS_AUTOCONF_USR) \
	--disable-static \
	--enable-shared \
	--disable-debug \
	--disable-mangling \
	--disable-texture-float \
	--disable-asm \
	--enable-pic \
	--disable-selinux \
	--enable-opengl \
	--disable-gles1 \
	--disable-gles2 \
	--disable-openvg \
	--$(call ptx/endis, PTXCONF_MESALIB_DRI)-dri \
	--$(call ptx/endis, PTXCONF_MESALIB_GLX)-glx \
	--$(call ptx/endis, PTXCONF_MESALIB_OSMESA)-osmesa \
	--enable-gbm \
	--disable-xa \
	--disable-d3d1x \
	--disable-xvmc \
	--disable-vdpau \
	--disable-va \
	--$(call ptx/endis, PTXCONF_MESALIB_XLIB_GLX)-xlib-glx \
	--disable-gallium-egl \
	--disable-gallium-gbm \
	--enable-shared-glapi \
	--enable-driglx-direct \
	--$(call ptx/endis,PTXCONF_XORG_SERVER_OPT_GLX_TLS)-glx-tls \
	--disable-gallium-g3dvl \
	--disable-gallium-llvm \
	--with-gallium-drivers=$(subst $(space),$(comma),$(MESALIB_GALLIUM_DRIVERS-y)) \
	--with-dri-drivers=$(subst $(space),$(comma),$(MESALIB_DRI_DRIVERS-y)) \
	--with-expat=$(SYSROOT)/usr


# the 32/64 bit options result in CFLAGS -> -m32 and -m64 which seem
# only to be available on x86

ifdef PTXCONF_ARCH_X86
MESALIB_CONF += \
	--enable-32-bit \
	--disable-64-bit
endif

# ----------------------------------------------------------------------------
# Extract 
# ----------------------------------------------------------------------------
$(STATEDIR)/mesalib.extract:
	@$(call targetinfo)
	@$(call clean, $(MESALIB_DIR))
	@$(call extract, MESALIB)
	@$(call patchin, MESALIB, $(MESALIB_DIR))
	@$(call touch)


$(STATEDIR)/mesalib.prepare:
	@$(call targetinfo)
	rm $(MESALIB_DIR)/configure
	cd $(MESALIB_DIR) &&  \
	export PKG_CONFIG_PATH=$(SYSROOT)/usr/lib/pkgconfig && \
	CFLAGS="-I$(SYSROOT)/usr/include -I$(SYSROOT)/usr/include/libdrm" \
	LDFLAGS=-L$(SYSROOT)/usr/lib \
	./autogen.sh --prefix=$(SYSROOT) --host=arm-cortexa9-linux-gnueabi \
	$(MESALIB_CONF)
	@$(call touch)


# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------

MESALIB_MAKE_OPT := HOST_CC=$(HOSTCC)

$(STATEDIR)/mesalib.compile:
	@$(call targetinfo)
	cp $(HOST_BUILDDIR)/Mesa-$(MESALIB_VERSION)/src/glsl/builtin_compiler $(MESALIB_DIR)/src/glsl/
	@$(call compile, MESALIB)
	@$(call touch)


# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------
$(STATEDIR)/mesalib.install:
	@$(call targetinfo)
	@$(call install, MESALIB)
	install $(MESALIB_DIR)/src/gbm/main/gbmint.h $(SYSROOT)/usr/include
	install $(MESALIB_DIR)/src/gbm/main/gbm.h $(SYSROOT)/usr/include
	install $(MESALIB_DIR)/src/gbm/main/common_drm.h $(SYSROOT)/usr/include
	install $(MESALIB_DIR)/src/gbm/main/gbm.pc $(SYSROOT)/usr/lib/pkgconfig
	@$(call touch)


# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

$(STATEDIR)/mesalib.targetinstall:
	@$(call targetinfo)

	@$(call install_init, mesalib)
	@$(call install_fixup, mesalib,PRIORITY,optional)
	@$(call install_fixup, mesalib,SECTION,base)
	@$(call install_fixup, mesalib,AUTHOR,"Robert Schwebel <r.schwebel@pengutronix.de>")
	@$(call install_fixup, mesalib,DESCRIPTION,missing)

ifdef PTXCONF_MESALIB_DRI
	@$(foreach lib, $(MESALIB_DRI_LIBS-y), \
		$(call install_copy, mesalib, 0, 0, 0644, -, /usr/lib/dri/$(lib)_dri.so);)
endif

	@$(call install_lib, mesalib, 0, 0, 0644, libGL)
#	@$(call install_lib, mesalib, 0, 0, 0644, libGLU)
ifdef PTXCONF_MESALIB_OSMESA
	@$(call install_lib, mesalib, 0, 0, 0644, libOSMesa)
endif
	@$(call install_lib, mesalib, 0, 0, 0644, libgbm)
	@$(call install_lib, mesalib, 0, 0, 0644, libglapi)

	@$(call install_finish, mesalib)

	@$(call touch)


# vim: syntax=make
