# -*-makefile-*-
#
# Copyright (C) 2012 Phytec
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

# Note to developers:
# The wayland package does not cross compile well.  It tries to build
# wayland-scanner using the cross compiler and then run it on the host.
# To get around this, you need to have a wayland-scanner binary installed
# already on your host.  As a stable wayland package for Ubuntu is not yet
# available, I have built the binary and put it in local_src
#
# To rebuild the host binary:
# First, you need to have libffi5 and libffi-dev installed on your
# development machine.
# Next, using the wayland tarball from local_src:
#	WLD=/tmp/install   # change this to another location if you prefer
#	LD_LIBRARY_PATH=$WLD/lib
#	PKG_CONFIG_PATH=$WLD/lib/pkgconfig/:$WLD/share/pkgconfig/
#	ACLOCAL="aclocal -I $WLD/share/aclocal"
#
#	export WLD LD_LIBRARY_PATH PKG_CONFIG_PATH ACLOCAL
#	./autogen.sh --prefix=$WLD
#	make


PACKAGES-$(PTXCONF_WAYLAND) += wayland

#
# The source tarball was taken from:
#	OPBU_Linux_Ubuntu_GLP1.6.6/ppa/packages
#
# According to the README, the source tree is available at:
#	git clone git://anongit.freedesktop.org/wayland/wayland
#

#
# Paths and names
#
WAYLAND_VERSION	:= 0.95.0
WAYLAND_MD5	:= 03b3adc4f62d4931214d97186fbbc5be
WAYLAND		:= wayland-$(WAYLAND_VERSION)
WAYLAND_SUFFIX	:= orig.tar.gz
WAYLAND_URL	:= file://$(PTXDIST_WORKSPACE)/local_src/wayland_$(WAYLAND_VERSION).$(WAYLAND_SUFFIX)
WAYLAND_DIR	:= $(BUILDDIR)/wayland-$(WAYLAND_VERSION)

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

# ----------------------------------------------------------------------------
# Extract 
# ----------------------------------------------------------------------------
$(STATEDIR)/wayland.extract:
	@$(call targetinfo)
	@$(call clean, $(WAYLAND_DIR))
	@$(call extract, WAYLAND)
	@$(call patchin, WAYLAND, $(WAYLAND_DIR))
	@$(call touch)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------


$(STATEDIR)/wayland.prepare:
	@$(call targetinfo)
	cd $(WAYLAND_DIR) &&  \
	export PKG_CONFIG_PATH=$(SYSROOT)/usr/lib/pkgconfig && \
	CFLAGS=-I$(SYSROOT)/usr/include \
	LDFLAGS=-L$(SYSROOT)/usr/lib \
	./autogen.sh --prefix=$(SYSROOT) --host=arm-cortexa9-linux-gnueabi \
	--disable-scanner
	@$(call touch)

# ----------------------------------------------------------------------------
#  Compile:
# ----------------------------------------------------------------------------
$(STATEDIR)/wayland.compile:

	@$(call targetinfo)
	cd $(WAYLAND_DIR) && $(MAKE)
	@$(call touch)


# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------
$(STATEDIR)/wayland.install:

	@$(call targetinfo)
	install $(WAYLAND_DIR)/src/wayland-server.h $(SYSROOT)/usr/include
	install $(WAYLAND_DIR)/src/wayland-client.h $(SYSROOT)/usr/include
	install $(WAYLAND_DIR)/src/wayland-util.h $(SYSROOT)/usr/include
	install $(WAYLAND_DIR)/src/wayland-egl.h $(SYSROOT)/usr/include
	install $(WAYLAND_DIR)/src/wayland-version.h $(SYSROOT)/usr/include
	install $(WAYLAND_DIR)/src/wayland-server-protocol.h \
				$(SYSROOT)/usr/include
	install $(WAYLAND_DIR)/src/wayland-client-protocol.h \
				$(SYSROOT)/usr/include
	install $(WAYLAND_DIR)/src/.libs/libwayland-server.so.0.0.0 \
		 		$(SYSROOT)/usr/lib/libwayland-server.so
	ln -sf $(SYSROOT)/usr/lib/libwayland-server.so \
				$(SYSROOT)/usr/lib/libwayland-server.so.0
	install $(WAYLAND_DIR)/src/.libs/libwayland-client.so.0.0.0 \
		 		$(SYSROOT)/usr/lib/libwayland-client.so
	ln -sf $(SYSROOT)/usr/lib/libwayland-client.so \
				$(SYSROOT)/usr/lib/libwayland-client.so.0
	install $(WAYLAND_DIR)/src/wayland-server.pc \
				$(SYSROOT)/usr/lib/pkgconfig
	install $(WAYLAND_DIR)/src/wayland-client.pc \
				$(SYSROOT)/usr/lib/pkgconfig
	@$(call touch)


# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

$(STATEDIR)/wayland.targetinstall:
	
	@$(call targetinfo)
	@$(call install_init, wayland)
	@$(call install_copy, wayland, 0, 0, 0755, \
		 $(WAYLAND_DIR)/src/.libs/libwayland-server.so.0.0.0, \
		 /usr/lib/libwayland-server.so.0.0.0)
	@$(call install_link, wayland, libwayland-server.so.0.0.0, \
		/usr/lib/libwayland-server.so)
	@$(call install_link, wayland, libwayland-server.so.0.0.0, \
		/usr/lib/libwayland-server.so.0)
	@$(call install_copy, wayland, 0, 0, 0755, \
		 $(WAYLAND_DIR)/src/.libs/libwayland-client.so.0.0.0, \
		 /usr/lib/libwayland-client.so.0.0.0)
	@$(call install_link, wayland, libwayland-client.so.0.0.0, \
		/usr/lib/libwayland-client.so)
	@$(call install_link, wayland, libwayland-client.so.0.0.0, \
		/usr/lib/libwayland-client.so.0)
	@$(call install_finish, wayland)
	@$(call touch)

